@@ -11,6 +11,11 @@ fs=$(df --output=fstype . | tail -n 1)
 # list features supported by all filesystems
 features=(use_linux "$@")
 
+# Some permissions tests don't work with root privs
+if [[ "$(id -u)" == "0" ]]; then
+    features+=(test_no_root)
+fi
+
 # disable tests that will not work on this filesystem
 case "$fs" in
 xfs | btrfs | bcachefs) ;;
